@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: albums.py 3723 2006-07-30 18:22:32Z piman $
+# $Id: albums.py 4024 2007-04-27 02:00:16Z piman $
 
 import os
 
@@ -16,6 +16,7 @@ import pango
 import config
 import const
 import qltk
+import stock
 import util
 
 from browsers._base import Browser
@@ -130,6 +131,11 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         except EnvironmentError: pass
         else:
             klass._Album._pattern = XMLFromPattern(klass._Album._pattern_text)
+        try:
+            klass._Album.cover = gtk.gdk.pixbuf_new_from_file_at_size(
+                stock.NO_ALBUM, 48, 48)
+        except RuntimeError:
+            klass._Album.cover = None
 
     @classmethod
     def toggle_covers(klass):
@@ -193,18 +199,18 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
     @classmethod
     def __add_songs(klass, library, added, model, update=True):
         albums = model.get_albums()
-        changed = set()
-        new = []
+        changed = set() # Keys of changed albums
+        new = [] # Added album instances
         for song in added:
             labelid = song.get("labelid", "")
             mbid = song.get("musicbrainz_albumid", "")
-            for alb in song("album").split("\n"):
-                key = song.album_key
-                if key not in albums:
-                    albums[key] = klass._Album(alb, labelid, mbid)
-                    new.append(albums[key])
-                albums[key].songs.add(song)
-                changed.add(key)
+            key = song.album_key
+            if key not in albums:
+                new_album = klass._Album(song("album"), labelid, mbid)
+                albums[key] = new_album
+                new.append(new_album)
+            albums[key].songs.add(song)
+            changed.add(key)
         for album in new:
             model.append(row=[album])
         if update: klass.__update(changed, model)
@@ -233,7 +239,6 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
             # but the same label ID are the same (since MB uses separate
             # MBIDs for each disc).
             self.key = (title, labelid or mbid)
-            self.cover = None
 
         def get(self, key, default="", connector=u" - "):
             if "~" in key[1:]:
@@ -413,7 +418,7 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
                 return
             album._model = self
             album._iter = iter
-            if album.title and album.cover is None:
+            if album.title and album.cover is type(album).cover:
                 if not self.__pending_covers:
                     copool.add(self.__scan_covers)
                 self.__pending_covers.append(album)
@@ -421,7 +426,7 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         def __scan_covers(self):
             while self.__pending_covers:
                 album = self.__pending_covers.pop()
-                if album._iter is None or album.cover is not None:
+                if album._iter is None or album.cover is not type(album).cover:
                     continue
                 song = list(album.songs)[0]
                 cover = song.find_cover()
@@ -551,7 +556,7 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         if None in albums:
             albums = [model[row][0] for row in model]
         for album in albums:
-            album.cover = None
+            album.cover = type(album).cover
             album.finalize()
 
     def __get_selected_albums(self, selection):
@@ -611,6 +616,12 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         if first:
             view.scroll_to_cell(first, use_align=True, row_align=0.5)
 
+    def unfilter(self):
+        view = self.get_children()[1].child
+        selection = view.get_selection()
+        selection.unselect_all()
+        selection.select_path((0,))
+
     def activate(self):
         self.get_children()[1].child.get_selection().emit('changed')
 
