@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: playlists.py 3689 2006-07-24 07:31:20Z piman $
+# $Id: playlists.py 3921 2006-10-21 03:54:54Z piman $
 
 import os
 import urllib
@@ -18,6 +18,7 @@ import config
 import const
 import formats
 import qltk
+import stock
 import util
 
 from tempfile import NamedTemporaryFile
@@ -284,6 +285,11 @@ class Playlists(gtk.VBox, Browser):
         super(Playlists, self).__init__(spacing=6)
         self.__main = bool(player)
         self.__view = view = RCMHintedTreeView()
+        self.__view.set_enable_search(True)
+        self.__view.set_search_column(0)
+        self.__view.set_search_equal_func(
+            lambda model, col, key, iter:
+            not model[iter][col].name.lower().startswith(key.lower()))
         self.__render = render = gtk.CellRendererText()
         render.set_property('ellipsize', pango.ELLIPSIZE_END)
         render.connect('editing-started', self.__start_editing)
@@ -447,7 +453,7 @@ class Playlists(gtk.VBox, Browser):
         rem.connect_object('activate', remove, model, iter)
         menu.prepend(rem)
 
-        ren = qltk.MenuItem(_("_Rename"), gtk.STOCK_EDIT)
+        ren = gtk.ImageMenuItem(stock.RENAME)
         keyval, mod = gtk.accelerator_parse("F2")
         ren.add_accelerator(
             'activate', self.accelerators, keyval, mod, gtk.ACCEL_VISIBLE)
