@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: _audio.py 3799 2006-08-27 01:26:56Z piman $
+# $Id: _audio.py 3944 2006-11-12 12:42:43Z luks $
 
 # Much of this code is highly optimized, because many of the functions
 # are called in tight loops. Don't change things just to make them
@@ -149,7 +149,7 @@ class AudioFile(dict):
                         role = key.split(":", 1)[1]
                         for value in self.list(key):
                             values.append("%s (%s)" % (value, role))
-                    values.extend(self.list("performer"))
+                values.extend(self.list("performer"))
                 return "\n".join(values)
             elif key == "basename":
                 return os.path.basename(self["~filename"]) or self["~filename"]
@@ -382,7 +382,8 @@ class AudioFile(dict):
                 # check for the album label number
                 if self.get("labelid", lfn + ".").lower() in lfn: score += 100
                 matches = filter(lambda s: s in lfn,
-                                 ["front", "cover", "jacket", "folder"])
+                                 ["front", "cover", "jacket", "folder",
+                                  "albumart"])
                 score += len(matches)
                 if score: images.append((score, os.path.join(base, fn)))
         # Highest score wins.
