@@ -4,12 +4,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: remote.py 2887 2006-02-23 06:57:15Z piman $
+# $Id: remote.py 3634 2006-07-14 19:38:41Z piman $
 
-import sys
-from util.uri import URI
 from formats._audio import AudioFile
-if sys.version_info < (2, 4): from sets import Set as set
+from util.uri import URI
 
 extensions = []
 
@@ -37,4 +35,6 @@ class RemoteFile(AudioFile):
         if k is None: return []
         else: return False
 
+    key = property(lambda self: self["~uri"])
+
 info = RemoteFile
