@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: player.py 3689 2006-07-24 07:31:20Z piman $
+# $Id: player.py 4027 2007-04-27 03:17:05Z piman $
 
 import gobject
 import gst
@@ -67,7 +67,8 @@ class PlaylistPlayer(gtk.Object):
         (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (object, int)),
         'paused': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
         'unpaused': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
-        'error': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (str, bool)),
+        'error': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+                  (object, str, bool)),
         }
 
     __gproperties__ = {
@@ -163,10 +164,8 @@ class PlaylistPlayer(gtk.Object):
     def error(self, message, lock):
         self.bin.set_property('uri', '')
         self.bin.set_state(gst.STATE_NULL)
-        self.song = self.info = None
-        self.paused = True
-        self.emit('error', message, lock)
-        self.emit('song-started', None)
+        self.emit('error', self.song, message, lock)
+        self.next()
 
     def seek(self, pos):
         """Seek to a position in the song, in milliseconds."""
@@ -288,7 +287,9 @@ playlist = None
 
 def init(pipeline, librarian):
     gst.debug_set_default_threshold(gst.LEVEL_ERROR)
-    if gst.element_make_from_uri(gst.URI_SRC, "file://", ""):
+    if gst.element_make_from_uri(
+        gst.URI_SRC,
+        "file:///Sebastian/Droge/please/choke/on/a/bucket/of/cocks", ""):
         global playlist
         playlist = PlaylistPlayer(pipeline or "gconfaudiosink", librarian)
         return playlist
