@@ -4,9 +4,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: ccb.py 2575 2005-12-21 03:27:31Z piman $
+# $Id: ccb.py 3197 2006-04-26 23:00:00Z piman $
 
 import gtk
+
 import config
 
 class ConfigCheckButton(gtk.CheckButton):
@@ -16,7 +17,7 @@ class ConfigCheckButton(gtk.CheckButton):
     It is *not* set to the current config value initially."""
 
     def __init__(self, label, section, option):
-        gtk.CheckButton.__init__(self, label)
+        super(ConfigCheckButton, self).__init__(label)
         self.connect('toggled', ConfigCheckButton.__toggled, section, option)
 
     def __toggled(self, section, option):
