@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: songsmenu.py 3886 2006-10-01 22:33:54Z piman $
+# $Id: songsmenu.py 3995 2007-02-10 23:38:42Z piman $
 
 import gtk
 
@@ -48,6 +48,9 @@ class SongsMenu(gtk.Menu):
             # Needed here to avoid a circular import; most browsers use
             # a SongsMenu, but SongsMenu needs access to the playlist
             # browser for this item.
+
+            # FIXME: Two things are now importing browsers, so we need
+            # some kind of inversion of control here.
             import browsers
             try: submenu = browsers.playlists.Menu(songs)
             except AttributeError: pass
@@ -67,13 +70,15 @@ class SongsMenu(gtk.Menu):
 
         if devices:
             import browsers
-            try: submenu = browsers.media.Menu(songs, library)
+            try: browsers.media
             except AttributeError: pass
             else:
-                b = gtk.ImageMenuItem(stock.DEVICES)
-                b.set_sensitive(can_add and len(submenu) > 0)
-                b.set_submenu(submenu)
-                self.append(b)
+                if browsers.media.MediaDevices in browsers.browsers:
+                    submenu = browsers.media.Menu(songs, library)
+                    b = gtk.ImageMenuItem(stock.DEVICES)
+                    b.set_sensitive(can_add and len(submenu) > 0)
+                    b.set_submenu(submenu)
+                    self.append(b)
 
         if remove or delete or edit:
             self.separate()
