@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: copool.py 3845 2006-09-17 05:51:21Z piman $
+# $Id: copool.py 4047 2007-04-30 03:49:58Z piman $
 
 """Manage a pool of routines using Python iterators."""
 
@@ -73,7 +73,7 @@ def step(funcid):
     """Force this function to iterate once."""
     if funcid in __routines:
         __routines[funcid][1]()
-    elif funcid in self.__paused:
+    elif funcid in __paused:
         __paused[funcid]()
     else:
         raise ValueError("no pooled routine %r" % funcid)
